#!/bin/sh

# ./create-freeciv-gtk3-nsi.sh <Freeciv files directory> <version>

./create-freeciv-gtk-qt-nsi.sh $1 $2 "gtk3" "GTK+3"
